# Generated by roxygen2 (4.1.1): do not edit by hand

S3method(as.character,rapport.inputs)
S3method(as.character,rapport.meta)
S3method(print,rapport)
S3method(print,rapport.info)
S3method(print,rapport.inputs)
S3method(print,rapport.meta)
export(get.tags)
export(is.rapport)
export(rapport)
export(rapport.body)
export(rapport.check.template)
export(rapport.docx)
export(rapport.example)
export(rapport.export)
export(rapport.html)
export(rapport.info)
export(rapport.inputs)
export(rapport.ls)
export(rapport.meta)
export(rapport.odt)
export(rapport.path)
export(rapport.path.add)
export(rapport.path.remove)
export(rapport.path.reset)
export(rapport.pdf)
export(rapport.renew)
export(rapport.rerun)
export(rapport.tangle)
export(tpl.body)
export(tpl.check)
export(tpl.example)
export(tpl.export)
export(tpl.header)
export(tpl.info)
export(tpl.inputs)
export(tpl.list)
export(tpl.meta)
export(tpl.paths)
export(tpl.paths.add)
export(tpl.paths.remove)
export(tpl.paths.reset)
export(tpl.renew)
export(tpl.rerun)
export(tpl.tangle)
importFrom(grDevices,dev.copy)
importFrom(grDevices,dev.list)
importFrom(grDevices,dev.off)
importFrom(grDevices,dev.size)
importFrom(pander,Pandoc)
importFrom(pander,Pandoc.brew)
importFrom(pander,evalsOptions)
importFrom(pander,p)
importFrom(pander,panderOptions)
importFrom(pander,pander_return)
importFrom(pander,pandoc.header)
importFrom(pander,pandoc.header.return)
importFrom(pander,pandoc.image.return)
importFrom(pander,redraw.recordedplot)
importFrom(rapportools,"label<-")
importFrom(rapportools,"rp.label<-")
importFrom(rapportools,adj.rle)
importFrom(rapportools,alike.integer)
importFrom(rapportools,capitalise)
importFrom(rapportools,catn)
importFrom(rapportools,fml)
importFrom(rapportools,is.boolean)
importFrom(rapportools,is.empty)
importFrom(rapportools,is.number)
importFrom(rapportools,is.string)
importFrom(rapportools,is.tabular)
importFrom(rapportools,is.variable)
importFrom(rapportools,label)
importFrom(rapportools,messagef)
importFrom(rapportools,name)
importFrom(rapportools,pct)
importFrom(rapportools,rp.label)
importFrom(rapportools,rp.name)
importFrom(rapportools,stopf)
importFrom(rapportools,tocamel)
importFrom(rapportools,trim.space)
importFrom(rapportools,vgsub)
importFrom(rapportools,warningf)
importFrom(stringr,str_extract_all)
importFrom(utils,download.file)
importFrom(utils,packageDescription)
importFrom(utils,tail)
importFrom(yaml,as.yaml)
importFrom(yaml,yaml.load)
