## test_file("inst/tests/test-inputs.R")

## TODO
## - test length-like attributes: what happens if you provide only min or max? does it default correctly
## - nchar: what is default min? 0? 1?
## - matchable (potential bug): dataset + value
## - guess.input.(name/title/description)
